@@ -20,25 +20,9 @@
 #include "tracksequencemanager.h"
 
 #include <QTimer>
+#include <QObject>
 
-class PlaylistDirtyObserver : public PlaylistObserver
-{
-public:
-    PlaylistDirtyObserver(DynamicPlaylist *parent, Playlist *playlist) :
-        PlaylistObserver(playlist),
-        m_parent(parent)
-    {
-
-    }
-
-    virtual void playlistItemDataHasChanged() Q_DECL_FINAL override
-    {
-        m_parent->slotSetDirty();
-    }
-
-private:
-    DynamicPlaylist *m_parent;
-};
+#include <algorithm>
 
 ////////////////////////////////////////////////////////////////////////////////
 // public methods
@@ -49,36 +33,47 @@ DynamicPlaylist::DynamicPlaylist(const PlaylistList &playlists,
                                  const QString &name,
                                  const QString &iconName,
                                  bool setupPlaylist,
-                                 bool synchronizePlaying) :
-    Playlist(collection, true),
-    m_playlists(playlists),
-    m_dirty(true),
-    m_synchronizePlaying(synchronizePlaying)
+                                 bool synchronizePlaying)
+  : Playlist(collection, true)
+  , m_dirty(true)
+  , m_synchronizePlaying(synchronizePlaying)
 {
     if(setupPlaylist)
         collection->setupPlaylist(this, iconName);
+
     setName(name);
     setAllowDuplicates(false);
-
     setSortingEnabled(false);
 
-    for(PlaylistList::ConstIterator it = playlists.constBegin(); it != playlists.constEnd(); ++it)
-        m_observers.append(new PlaylistDirtyObserver(this, *it));
+    for(const auto playlist : playlists) {
+        m_playlists << QPointer<Playlist>(playlist);
 
-    connect(CollectionList::instance(), SIGNAL(signalCollectionChanged()), this, SLOT(slotSetDirty()));
+        connect(&(playlist->signaller), &PlaylistInterfaceSignaller::playingItemDataChanged,
+                this, &DynamicPlaylist::slotSetDirty);
+    }
+
+    connect(CollectionList::instance(), &CollectionList::signalCollectionChanged,
+            this, &DynamicPlaylist::slotSetDirty);
 }
 
 DynamicPlaylist::~DynamicPlaylist()
 {
-    lower();
+    // The Playlist dtor will later clear items when it runs, we need to make
+    // sure the list is accurate first while we're still able to
 
-    foreach(PlaylistObserver *observer, m_observers)
-        delete observer;
+    checkUpdateItems();
+
+    lower();
 }
 
 void DynamicPlaylist::setPlaylists(const PlaylistList &playlists)
 {
-    m_playlists = playlists;
+    m_playlists.clear();
+
+    for(const auto playlist : playlists) {
+        m_playlists << QPointer<Playlist>(playlist);
+    }
+
     updateItems();
 }
 
@@ -88,8 +83,11 @@ void DynamicPlaylist::setPlaylists(const PlaylistList &playlists)
 
 void DynamicPlaylist::slotReload()
 {
-    for(PlaylistList::Iterator it = m_playlists.begin(); it != m_playlists.end(); ++it)
-        (*it)->slotReload();
+    for(const auto playlist : m_playlists) {
+        if(!playlist)
+            continue;
+        playlist->slotReload();
+    }
 
     checkUpdateItems();
 }
@@ -102,23 +100,23 @@ void DynamicPlaylist::lower(QWidget *top)
     if(playing()) {
         PlaylistList l;
         l.append(this);
-        for(PlaylistList::Iterator it = m_playlists.begin();
-            it != m_playlists.end(); ++it)
-        {
-            (*it)->synchronizePlayingItems(l, true);
+
+        for(const auto playlist : m_playlists) {
+            if(!playlist)
+                continue;
+            playlist->synchronizePlayingItems(l, true);
         }
     }
 
-    PlaylistItemList list = PlaylistItem::playingItems();
-    for(PlaylistItemList::Iterator it = list.begin(); it != list.end(); ++it) {
-        if((*it)->playlist() == this) {
-            list.erase(it);
-            break;
-        }
-    }
+    const auto playlistItems = PlaylistItem::playingItems();
+    const auto itemIt = std::find_if(
+        playlistItems.begin(), playlistItems.end(),
+        [this](const PlaylistItem *item) {
+            return item->playlist() != this;
+        });
 
-    if(!list.isEmpty())
-        TrackSequenceManager::instance()->setCurrentPlaylist(list.front()->playlist());
+    if(itemIt != playlistItems.end())
+        TrackSequenceManager::instance()->setCurrentPlaylist((*itemIt)->playlist());
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -147,15 +145,20 @@ void DynamicPlaylist::updateItems()
 {
     PlaylistItemList siblings;
 
-    for(PlaylistList::ConstIterator it = m_playlists.constBegin(); it != m_playlists.constEnd(); ++it)
-        siblings += (*it)->items();
+    for(const auto playlist : qAsConst(m_playlists)) {
+        if(!playlist)
+            continue;
+        siblings += playlist->items();
+    }
 
     if(m_siblings != siblings) {
         m_siblings = siblings;
         this->synchronizeItemsTo(siblings);
 
         if(m_synchronizePlaying) {
-            synchronizePlayingItems(m_playlists, true);
+            for(const auto playlist : m_playlists) {
+                synchronizePlayingItems(playlist, true);
+            }
         }
     }
 }
